@@ -64,7 +64,7 @@ class Exceptions:
 
 class KinesisAnalyticsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html)
     """
 
@@ -86,7 +86,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_cloud_watch_logging_option)
         """
 
@@ -96,7 +96,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input)
         """
 
@@ -111,7 +111,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input_processing_configuration)
         """
 
@@ -121,7 +121,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_output)
         """
 
@@ -135,7 +135,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_reference_data_source)
         """
 
@@ -143,7 +143,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#can_paginate)
         """
 
@@ -151,17 +151,17 @@ class KinesisAnalyticsClient(BaseClient):
         self,
         *,
         ApplicationName: str,
-        ApplicationDescription: str = None,
-        Inputs: Sequence["InputTypeDef"] = None,
-        Outputs: Sequence["OutputTypeDef"] = None,
-        CloudWatchLoggingOptions: Sequence["CloudWatchLoggingOptionTypeDef"] = None,
-        ApplicationCode: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        ApplicationDescription: str = ...,
+        Inputs: Sequence["InputTypeDef"] = ...,
+        Outputs: Sequence["OutputTypeDef"] = ...,
+        CloudWatchLoggingOptions: Sequence["CloudWatchLoggingOptionTypeDef"] = ...,
+        ApplicationCode: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateApplicationResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#create_application)
         """
 
@@ -171,7 +171,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application)
         """
 
@@ -185,7 +185,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_cloud_watch_logging_option)
         """
 
@@ -195,7 +195,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_input_processing_configuration)
         """
 
@@ -205,7 +205,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_output)
         """
 
@@ -215,7 +215,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_reference_data_source)
         """
 
@@ -223,47 +223,47 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#describe_application)
         """
 
     def discover_input_schema(
         self,
         *,
-        ResourceARN: str = None,
-        RoleARN: str = None,
-        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = None,
-        S3Configuration: "S3ConfigurationTypeDef" = None,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None
+        ResourceARN: str = ...,
+        RoleARN: str = ...,
+        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = ...,
+        S3Configuration: "S3ConfigurationTypeDef" = ...,
+        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = ...
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#discover_input_schema)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#generate_presigned_url)
         """
 
     def list_applications(
-        self, *, Limit: int = None, ExclusiveStartApplicationName: str = None
+        self, *, Limit: int = ..., ExclusiveStartApplicationName: str = ...
     ) -> ListApplicationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_applications)
         """
 
@@ -271,7 +271,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         Retrieves the list of key-value tags assigned to the application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_tags_for_resource)
         """
 
@@ -281,7 +281,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#start_application)
         """
 
@@ -289,7 +289,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#stop_application)
         """
 
@@ -297,7 +297,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         Adds one or more key-value tags to a Kinesis Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#tag_resource)
         """
 
@@ -305,7 +305,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
         Removes one or more tags from a Kinesis Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#untag_resource)
         """
 
@@ -319,6 +319,6 @@ class KinesisAnalyticsClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#update_application)
         """
